pub struct StageHandle { /* private fields */ }Expand description
Handle to a pipeline stage placed between a source and a sink.
In STREAM 6 the only stage is the identity stage (see
StageHandle::identity); stream/pipe accepts identity stages and rejects
any other stage kind.
Implementations
Sourceimpl StageHandle
impl StageHandle
Sourcepub fn is_identity(&self) -> bool
pub fn is_identity(&self) -> bool
Returns true when this stage is the identity pass-through stage.